@@ -419,6 +419,7 @@ def train_loop(
     checkpoint_every_n=1000,
     checkpoint_max_to_keep=7,
     record_summaries=True,
+    log_real_time=None,
     **kwargs):
   """Trains a model using eager + functions.
 
@@ -449,6 +450,8 @@ def train_loop(
     checkpoint_max_to_keep:
       int, the number of most recent checkpoints to keep in the model directory.
     record_summaries: Boolean, whether or not to record summaries.
+    log_real_time: Decide whether or not you want to log loss at each step to Picsellia.
+      If not None, it equals the experiment object where to log.
     **kwargs: Additional keyword arguments for configuration override.
   """
   ## Parse the configs
@@ -630,7 +633,8 @@ def train_loop(
                        num_steps_per_iteration):
 
           loss = _dist_train_step(train_input_iter)
-
+          if log_real_time is not None:
+            log_real_time.log("loss",[float(loss.numpy())], 'line')
           time_taken = time.time() - last_step_time
           last_step_time = time.time()
 
@@ -638,12 +642,20 @@ def train_loop(
               'steps_per_sec', num_steps_per_iteration * 1.0 / time_taken,
               step=global_step)
 
-          if global_step.value() - logged_step >= 100:
-            tf.logging.info(
-                'Step {} per-step time {:.3f}s loss={:.3f}'.format(
-                    global_step.value(), time_taken / num_steps_per_iteration,
-                    loss))
-            logged_step = global_step.value()
+          if train_steps <= 10000:
+            if global_step.value() - logged_step >= 10:
+              print(
+                  'Step {} per-step time {:.3f}s loss={:.3f}'.format(
+                      global_step.value(), time_taken / num_steps_per_iteration,
+                      loss))
+              logged_step = global_step.value()
+          else:
+            if global_step.value() - logged_step >= int(train_steps/1000):
+              print(
+                  'Step {} per-step time {:.3f}s loss={:.3f}'.format(
+                      global_step.value(), time_taken / num_steps_per_iteration,
+                      loss))
+              logged_step = global_step.value()
 
           if ((int(global_step.value()) - checkpointed_step) >=
               checkpoint_every_n):
