@@ -78,7 +78,11 @@ def tf_vars_generator(
                 pass
 
             encoded_jpg = io.BytesIO()
-            image.save(encoded_jpg, format="JPEG")
+            try:
+                image.save(encoded_jpg, format="JPEG")
+            except OSError:
+                image.convert('RGB')
+                image.save(encoded_jpg, format="JPEG")                
             encoded_jpg = encoded_jpg.getvalue()
 
             width, height = image.size
